==> zio-aws-elasticloadbalancingv2_3-5.17.129.3-sources.jar: zio/aws/elasticloadbalancingv2/model/ModifyTargetGroupResponse.scala <==
package zio.aws.elasticloadbalancingv2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ModifyTargetGroupResponse(
    targetGroups: Option[
      Iterable[zio.aws.elasticloadbalancingv2.model.TargetGroup]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticloadbalancingv2.model.ModifyTargetGroupResponse = {
    import ModifyTargetGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticloadbalancingv2.model.ModifyTargetGroupResponse
      .builder()
      .optionallyWith(
        targetGroups.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.targetGroups)
      .build()
  }
  def asReadOnly
      : zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupResponse.ReadOnly =
    zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupResponse
      .wrap(buildAwsValue())
}
object ModifyTargetGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticloadbalancingv2.model.ModifyTargetGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupResponse =
      zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupResponse(
        targetGroups.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def targetGroups: Option[
      List[zio.aws.elasticloadbalancingv2.model.TargetGroup.ReadOnly]
    ]
    def getTargetGroups: ZIO[Any, AwsError, List[
      zio.aws.elasticloadbalancingv2.model.TargetGroup.ReadOnly
    ]] = AwsError.unwrapOptionField("targetGroups", targetGroups)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticloadbalancingv2.model.ModifyTargetGroupResponse
  ) extends zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupResponse.ReadOnly {
    override val targetGroups: Option[
      List[zio.aws.elasticloadbalancingv2.model.TargetGroup.ReadOnly]
    ] = scala
      .Option(impl.targetGroups())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.elasticloadbalancingv2.model.TargetGroup.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticloadbalancingv2.model.ModifyTargetGroupResponse
  ): zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-elasticloadbalancingv2_3-5.17.208.2-sources.jar: zio/aws/elasticloadbalancingv2/model/ModifyTargetGroupResponse.scala <==
package zio.aws.elasticloadbalancingv2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ModifyTargetGroupResponse(
    targetGroups: Optional[
      Iterable[zio.aws.elasticloadbalancingv2.model.TargetGroup]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticloadbalancingv2.model.ModifyTargetGroupResponse = {
    import ModifyTargetGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticloadbalancingv2.model.ModifyTargetGroupResponse
      .builder()
      .optionallyWith(
        targetGroups.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.targetGroups)
      .build()
  }
  def asReadOnly
      : zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupResponse.ReadOnly =
    zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupResponse
      .wrap(buildAwsValue())
}
object ModifyTargetGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticloadbalancingv2.model.ModifyTargetGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupResponse =
      zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupResponse(
        targetGroups.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def targetGroups: Optional[
      List[zio.aws.elasticloadbalancingv2.model.TargetGroup.ReadOnly]
    ]
    def getTargetGroups: ZIO[Any, AwsError, List[
      zio.aws.elasticloadbalancingv2.model.TargetGroup.ReadOnly
    ]] = AwsError.unwrapOptionField("targetGroups", targetGroups)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticloadbalancingv2.model.ModifyTargetGroupResponse
  ) extends zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupResponse.ReadOnly {
    override val targetGroups: Optional[
      List[zio.aws.elasticloadbalancingv2.model.TargetGroup.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.targetGroups())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.elasticloadbalancingv2.model.TargetGroup.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticloadbalancingv2.model.ModifyTargetGroupResponse
  ): zio.aws.elasticloadbalancingv2.model.ModifyTargetGroupResponse.ReadOnly =
    new Wrapper(impl)
}
